#
# spec file for package ghc-shakespeare
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name shakespeare
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.0.25.1
Release:        bp155.2.15
Summary:        A toolkit for making compile-time interpolated templates
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-blaze-html-devel
BuildRequires:  ghc-blaze-markup-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-th-lift-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-hspec-devel
%endif

%description
Shakespeare is a family of type-safe, efficient template languages.
Shakespeare templates are expanded at compile-time, ensuring that all
interpolated variables are in scope. Variables are interpolated according to
their type through a typeclass.

Shakespeare templates can be used inline with a quasi-quoter or in an external
file.

Note there is no dependency on haskell-src-extras. Instead Shakespeare believes
logic should stay out of templates and has its own minimal Haskell parser.

Packages that use this: xml-hamlet

Please see the documentation at
<http://www.yesodweb.com/book/shakespearean-templates> for more details.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md

%changelog
* Thu Dec 23 2021 Peter Simons <psimons@suse.com>
- Update shakespeare to version 2.0.25.1.
  [#]## 2.0.25.1
  * Support for GHC 9.2 and aeson 2 [#260](https://github.com/yesodweb/shakespeare/pull/260)
* Tue Oct 12 2021 psimons@suse.com
- Update shakespeare to version 2.0.25 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Fri Aug 28 2020 psimons@suse.com
- Update shakespeare to version 2.0.25.
  [#]## 2.0.25
  * Support for GHC 9.0 [#254](https://github.com/yesodweb/shakespeare/pull/254)
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Fri Jun 19 2020 psimons@suse.com
- Update shakespeare to version 2.0.24.1.
  [#]## 2.0.24.1
  * Derive Lift instances wherever possible [#252](https://github.com/yesodweb/shakespeare/pull/252)
* Tue Jun  9 2020 psimons@suse.com
- Add shakespeare at version 2.0.24.
